## Version 0.11.8

This release includes a minor version bump and a significant refactor in the usage of the slugify function to enhance consistency in naming conventions across different classes.

### New Features

- Refactored slugify usage to ensure consistent naming conventions across various database document store classes. This change includes removing unnecessary slugify usage and adding it where needed for uniformity. (dd2f66) (Eric Ma)

### Bug Fixes

- None

### Deprecations

- None
